##  Using Shapes from Other Templates
You can change a fact sheet's shape to one from a different template. To do this, do the following:
  1. Open a diagram in edit mode.
  2. Choose the fact sheet in the editor.
  3. Select the desired template from the Fact Sheet Shape Template dropdown in the right panel.
You can only change the shape of fact sheets individually. Selecting and changing the shapes for multiple fact sheets at once is not supported.
![An animated image showing how to switch to a shape from another template.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioe287b931cff04c83969c0c9297a88a7c_LowRes.gif)


YesNo
Send
